@@ -1,10 +1,9 @@
 #' Size scale.
 #' 
+#' @name scale_size
 #' @inheritParams scale_x_continuous
 #' @param range a numeric vector of length 2 that specifies the minimum and
 #'   maximum size of the plotting symbol after transformation.
-#' @rdname scale_size
-#' @export
 #' @examples
 #' \donttest{
 #' (p <- qplot(mpg, cyl, data=mtcars, size=cyl))
@@ -27,6 +26,10 @@
 #' # scale_size_manual:
 #' last_plot() + scale_size_manual(values=c(2,4,6))
 #' }
+NULL
+
+#' @rdname scale_size
+#' @export
 scale_size_continuous <- function(..., range = c(1, 6)) {
   continuous_scale("size", "size_c", rescale_pal(range), ...)
 }
@@ -41,8 +44,3 @@ scale_size_discrete <- function(..., range = c(1, 6)) {
   discrete_scale("size", "size_d",
     function(n) seq(range[1], range[2], length = n), ...)
 }
-
-icon.size <- function() {
-  pos <- c(0.15, 0.3, 0.5, 0.75)
-  circleGrob(pos, pos, r=(c(0.1, 0.2, 0.3, 0.4)/2.5), gp=gpar(fill="grey50", col=NA))
-}
