@@ -13,7 +13,7 @@ save_vtest("dates along x, default breaks")
 dt + scale_x_date(breaks = date_breaks("2 weeks"))
 save_vtest("scale_x_date(breaks = date_breaks(\"2 weeks\"))")
 dt + scale_x_date(breaks = "3 weeks")
-save_vtest("scale_x_date(breaks = date_breaks(\"3 weeks\"))")
+save_vtest("scale_x_date(breaks = \"3 weeks\")")
 
 dt + scale_x_date(labels = date_format("%m/%d"))
 save_vtest("scale_x_date(labels = date_format(\"%m/%d\"))")
@@ -27,6 +27,6 @@ save_vtest("dates along y, default breaks")
 dt + scale_y_date(breaks = date_breaks("2 weeks"))
 save_vtest("scale_y_date(breaks = date_breaks(\"2 weeks\"))")
 dt + scale_y_date(breaks = "3 weeks")
-save_vtest("scale_y_date(breaks = date_breaks(\"3 weeks\"))")
+save_vtest("scale_y_date(breaks = \"3 weeks\")")
 
 end_vcontext()
\ No newline at end of file
